# Whether we should verify tarball signature with GPGv2.
%global verify_tarball_signature %{nil}

# The source directory.
%global source_directory 5.2-stable

Summary:       Tool for creating supermin appliances
Name:          supermin
Version:       5.2.0
Release:       %mkrel 2
License:       GPLv2+
Group:         Development/Tools
URL:           http://people.redhat.com/~rjones/supermin/
Source0:       http://download.libguestfs.org/supermin/%{source_directory}/%{name}-%{version}.tar.gz
Source1:       http://download.libguestfs.org/supermin/%{source_directory}/%{name}-%{version}.tar.gz.sig
# Keyring used to verify tarball signature.
Source2:       libguestfs.keyring

BuildRequires: perl
BuildRequires: rpm
BuildRequires: rpm-devel
BuildRequires: dnf
BuildRequires: dnf-plugins-core
BuildRequires: e2fsprogs
BuildRequires: e2fsprogs-devel
BuildRequires: findutils
BuildRequires: glibc-static-devel
BuildRequires: ocaml
BuildRequires: ocaml-findlib-devel

# (ngompa): These are urpmi-specific dependencies
BuildRequires: fakeroot
BuildRequires: urpmi

# These are required only to run the tests.  We could patch out the
# tests to not require these packages.
BuildRequires: augeas hivex kernel tar

Requires:      rpm
Requires:      urpmi
Requires:      dnf-plugins-core
Requires:      util-linux-ng
Requires:      cpio
Requires:      tar
# RHBZ#771310
Requires:      e2fsprogs >= 1.42

# (ngompa): These are urpmi-specific dependencies
Requires:      fakeroot
Requires:      urpmi

# For automatic RPM dependency generation.
# See: http://www.rpm.org/wiki/PackagerDocs/DependencyGenerator
Source3:       supermin.attr
Source4:       supermin-find-requires


%description
Supermin is a tool for building supermin appliances.  These are tiny
appliances (similar to virtual machines), usually around 100KB in
size, which get fully instantiated on-the-fly in a fraction of a
second when you need to boot one of them.

%package devel
Summary:       Development tools for %{name}
Requires:      %{name}%{?_isa} = %{version}-%{release}
Requires:      rpm-build


%description devel
%{name}-devel contains development tools for %{name}.

It just contains tools for automatic RPM dependency generation
from supermin appliances.


%prep
%if 0%{verify_tarball_signature}
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%endif
%autosetup -p1

%build
%configure --disable-network-tests
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0644 %{SOURCE3} %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0755 %{SOURCE4} %{buildroot}%{_rpmconfigdir}/

%check

# Disable failing test for now
# Fedora seems to have it passing since f21 but their package is very
# different, and for example uses dietlibc
%ifarch %{arm}
export SKIP_TEST_EXECSTACK=1
%endif

make check || {
     cat tests/test-suite.log
     exit 1
}

%files
%license COPYING
%doc README examples/build-basic-vm.sh
%{_bindir}/supermin
%{_mandir}/man1/supermin.1*

%files devel
%{_rpmconfigdir}/fileattrs/supermin.attr
%{_rpmconfigdir}/supermin-find-requires


%changelog
* Sat Jan 09 2021 ngompa <ngompa> 5.2.0-2.mga8
+ Revision: 1670207
- Use parallel make now that it works
- Add missing BR to detect DNF for supermin

* Wed Jun 10 2020 joequant <joequant> 5.2.0-1.mga8
+ Revision: 1591818
- update to 5.2.0

* Sun Feb 16 2020 umeabot <umeabot> 5.1.20-2.mga8
+ Revision: 1531292
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Sep 10 2019 tv <tv> 5.1.20-1.mga8
+ Revision: 1439351
- new release

* Thu Oct 04 2018 umeabot <umeabot> 5.1.19-5.mga7
+ Revision: 1317394
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Sun May 06 2018 daviddavid <daviddavid> 5.1.19-3.mga7
+ Revision: 1226653
- no need to call autoconf thus fixing build

* Tue Feb 13 2018 daviddavid <daviddavid> 5.1.19-2.mga7
+ Revision: 1200802
- add upstream patch to fix bytes/string problems

* Thu Oct 12 2017 tv <tv> 5.1.19-1.mga7
+ Revision: 1171263
- new release

* Fri Sep 01 2017 tv <tv> 5.1.17-4.mga7
+ Revision: 1150499
- rebuild for new rpm

* Thu Jul 20 2017 tv <tv> 5.1.17-3.mga7
+ Revision: 1125673
- revert unexplained s/urpmi/dnf/: this breaks badly the build of libguestfs

* Tue Nov 22 2016 pterjan <pterjan> 5.1.17-2.mga6
+ Revision: 1068830
- Disable a failing test on arm for now

* Tue Nov 01 2016 ngompa <ngompa> 5.1.17-1.mga6
+ Revision: 1064451
- Add tests to run as part of the build
- Upgrade to 5.1.17

* Mon Sep 26 2016 pterjan <pterjan> 5.1.15-5.mga6
+ Revision: 1056512
- Rebuild for fix in ocaml

* Wed Apr 27 2016 tv <tv> 5.1.15-4.mga6
+ Revision: 1006745
- requires fakeroot else it fails at runtime...

* Wed Apr 27 2016 tv <tv> 5.1.15-3.mga6
+ Revision: 1006739
- BR fakeroot in order to fix mga support

* Tue Apr 26 2016 tv <tv> 5.1.15-2.mga6
+ Revision: 1006633
- package an example
- add a devel package
- BR rpm-devel, since it is now used instead of invoking rpm
- switch to %%autopatch

* Tue Apr 26 2016 tv <tv> 5.1.15-1.mga6
+ Revision: 1006616
- new release

* Sat Feb 06 2016 umeabot <umeabot> 5.1.10-5.mga6
+ Revision: 941100
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 5.1.10-4.mga5
+ Revision: 743209
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.1.10-3.mga5
+ Revision: 689618
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 joequant <joequant> 5.1.10-2.mga5
+ Revision: 673324
- rebuild with correct fakeroot

* Sat Sep 06 2014 tv <tv> 5.1.10-1.mga5
+ Revision: 672651
- new release

* Thu Aug 28 2014 joequant <joequant> 5.1.9-1.mga5
+ Revision: 669013
- update to 5.1.9

* Mon Jun 09 2014 tmb <tmb> 5.1.8-5.mga5
+ Revision: 635221
- require e2fsprogs instead of /usr/sbin/mke2fs

* Wed May 28 2014 joequant <joequant> 5.1.8-4.mga5
+ Revision: 627290
- add fakeroot to buildrequires

* Wed May 28 2014 joequant <joequant> 5.1.8-2.mga5
+ Revision: 627277
- add fakeroot requires

* Wed May 28 2014 joequant <joequant> 5.1.8-1.mga5
+ Revision: 627256
- upgrade to 5.1.8

* Sat Oct 19 2013 umeabot <umeabot> 4.1.5-2.mga5
+ Revision: 536673
- Mageia 4 Mass Rebuild

* Tue Sep 24 2013 joequant <joequant> 4.1.5-1.mga4
+ Revision: 485253
- upgrade to 4.1.5

* Mon Sep 02 2013 joequant <joequant> 4.1.4-1.mga4
+ Revision: 474314
- sync with 4.1.4
- modify with upstream patches

* Sat Aug 17 2013 joequant <joequant> 4.1.3-1.mga4
+ Revision: 467311
- upgrade to 4.1.3

* Fri Aug 16 2013 joequant <joequant> 4.1.1-2.mga4
+ Revision: 466904
- add xz decompression

* Tue Aug 13 2013 joequant <joequant> 4.1.1-1.mga4
+ Revision: 466206
- more spec tweaks
- more supermin tweaks
- use urpmq to get rpms
- imported package supermin

